summaryrefslogtreecommitdiffstats
path: root/ui/aura/window_tree_host_win.cc
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-05 18:59:03 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-05 18:59:03 +0000
commit2d6eb74a95f9aa8edb777edc03e6915354bdd96f (patch)
tree4aa3c19921720fb0ff020335128f9ce46c956fde /ui/aura/window_tree_host_win.cc
parentd0b28895943cb6ac3a37920268ac93347b81b1c9 (diff)
downloadchromium_src-2d6eb74a95f9aa8edb777edc03e6915354bdd96f.zip
chromium_src-2d6eb74a95f9aa8edb777edc03e6915354bdd96f.tar.gz
chromium_src-2d6eb74a95f9aa8edb777edc03e6915354bdd96f.tar.bz2
Rename RootWindowObserver -> WindowTreeHostObserver.
Move observer management and notification to WTH. R=sky@chromium.org http://crbug.com/348874 Review URL: https://codereview.chromium.org/186423002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@255108 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/aura/window_tree_host_win.cc')
-rw-r--r--ui/aura/window_tree_host_win.cc9
1 files changed, 4 insertions, 5 deletions
diff --git a/ui/aura/window_tree_host_win.cc b/ui/aura/window_tree_host_win.cc
index 33d50e6..eb3af31 100644
--- a/ui/aura/window_tree_host_win.cc
+++ b/ui/aura/window_tree_host_win.cc
@@ -131,14 +131,14 @@ void WindowTreeHostWin::SetBounds(const gfx::Rect& bounds) {
window_rect.bottom - window_rect.top,
SWP_NOMOVE | SWP_NOOWNERZORDER | SWP_NOREDRAW | SWP_NOREPOSITION);
// Explicity call NotifyHostResized when the scale has changed because
// the window size may not have changed.
float current_scale = compositor()->device_scale_factor();
float new_scale = gfx::Screen::GetScreenFor(
delegate_->AsDispatcher()->window())->GetDisplayNearestWindow(
delegate_->AsDispatcher()->window()).device_scale_factor();
if (current_scale != new_scale)
- NotifyHostResized(bounds.size());
+ OnHostResized(bounds.size());
}
gfx::Insets WindowTreeHostWin::GetInsets() const {
@@ -282,8 +282,7 @@ LRESULT WindowTreeHostWin::OnNCActivate(UINT message,
}
void WindowTreeHostWin::OnMove(const gfx::Point& point) {
- if (delegate_)
- delegate_->OnHostMoved(point);
+ OnHostMoved(point);
}
void WindowTreeHostWin::OnPaint(HDC dc) {
@@ -299,7 +298,7 @@ void WindowTreeHostWin::OnSize(UINT param, const gfx::Size& size) {
// Minimizing resizes the window to 0x0 which causes our layout to go all
// screwy, so we just ignore it.
if (delegate_ && param != SIZE_MINIMIZED)
- NotifyHostResized(size);
+ OnHostResized(size);
}
namespace test {
@@ -131,14 +131,14 @@ void WindowTreeHostWin::SetBounds(const gfx::Rect& bounds) {
window_rect.bottom - window_rect.top,
SWP_NOMOVE | SWP_NOOWNERZORDER | SWP_NOREDRAW | SWP_NOREPOSITION);
- // Explicity call NotifyHostResized when the scale has changed because
+ // Explicity call OnHostResized when the scale has changed because
// the window size may not have changed.
float current_scale = compositor()->device_scale_factor();